@@ -18,7 +18,7 @@ from typing import List
 
 import jpype
 import requests
-import appkit
+from ergpy import appkit
 
 
 # Functions
